@@ -5,8 +5,9 @@
 
 from __future__ import annotations
 
-import copy
-from typing import Any, Callable, Dict, Iterable, Optional, Union
+import math
+import warnings
+from typing import Any, Callable, Dict, Iterable, List, Optional, Union
 
 from torchmetrics import Metric, MetricCollection
 
@@ -35,13 +36,14 @@ def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end:
     if isinstance(eval_interval, str):
         eval_interval = Time.from_timestring(eval_interval)
 
-    if eval_interval.unit not in (TimeUnit.EPOCH, TimeUnit.BATCH):
-        raise ValueError('The `eval_interval` must have units of EPOCH or BATCH, or be a function.')
+    if eval_interval.unit not in (TimeUnit.EPOCH, TimeUnit.BATCH, TimeUnit.DURATION):
+        raise ValueError('The `eval_interval` must have units of EPOCH, BATCH, DURATION or be a function.')
 
     last_batch_seen = -1
 
     def should_eval(state: State, event: Event):
-        if int(eval_interval) <= 0:
+        # `TimeUnit.Duration` value is a float from `[0.0, 1.0)`
+        if not eval_interval.unit == TimeUnit.DURATION and int(eval_interval) <= 0:
             return False
         nonlocal last_batch_seen  # required to use the last_batch_seen from the outer function scope
 
@@ -59,6 +61,31 @@ def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end:
             last_batch_seen = state.timestamp.batch
             return True
 
+        if eval_interval.unit == TimeUnit.DURATION:
+            assert state.max_duration is not None, 'max_duration should not be None'
+            if state.dataloader_len is None:
+                raise RuntimeError(
+                    f'Evaluation interval of type `dur` or {TimeUnit.DURATION} requires the dataloader to be sized.')
+            if state.max_duration.unit == TimeUnit.EPOCH and int(
+                    state.timestamp.batch) % math.ceil(state.max_duration.value * float(eval_interval) *
+                                                       state.dataloader_len) == 0 and event == Event.BATCH_END:
+                last_batch_seen = state.timestamp.batch
+                return True
+            elif state.max_duration.unit == TimeUnit.BATCH and int(state.timestamp.batch) % math.ceil(
+                    state.max_duration.value * eval_interval.value) == 0 and event == Event.BATCH_END:
+                last_batch_seen = state.timestamp.batch
+                return True
+            elif state.max_duration.unit == TimeUnit.SAMPLE and event == Event.BATCH_END:
+                # If last sample in batch is not evenly divisible by eval_interval, perform evaluation in next batch
+                if int(state.timestamp.batch) > 0:
+                    samples_in_a_batch = int(state.timestamp.sample) // int(state.timestamp.batch)
+                    if int(state.timestamp.sample) // math.ceil(state.max_duration.value * eval_interval) != int(
+                            state.timestamp.sample - samples_in_a_batch) // math.ceil(
+                                state.max_duration.value * eval_interval):
+                        last_batch_seen = state.timestamp.batch
+                        return True
+            elif state.max_duration.unit == TimeUnit.TOKEN and event == Event.BATCH_END:
+                raise ValueError(f'Evaluation interval of type `dur` is not supported yet for max_duration as `tok`')
         return False
 
     return should_eval
@@ -71,11 +98,10 @@ class Evaluator:
 
     .. doctest::
 
-       >>> from torchmetrics.classification.accuracy import Accuracy
        >>> eval_evaluator = Evaluator(
        ...     label="myEvaluator",
        ...     dataloader=eval_dataloader,
-       ...     metrics=Accuracy()
+       ...     metric_names=['Accuracy']
        ... )
        >>> trainer = Trainer(
        ...     model=model,
@@ -89,8 +115,12 @@ class Evaluator:
         label (str): Name of the Evaluator.
         dataloader (DataSpec | Iterable | Dict[str, Any]): Iterable that yields batches, a :class:`.DataSpec`
             for evaluation, or a Dict of :class:`.DataSpec` kwargs.
-        metrics (torchmetrics.Metric | torchmetrics.MetricCollection): :class:`torchmetrics.Metric` to log.
-            ``metrics`` will be deep-copied to ensure that each evaluator updates only its ``metrics``.
+        metric_names: The list of metric names to compute.
+            Each value in this list can be a regex string (e.g. "Accuracy", "f1" for "BinaryF1Score",
+            "Top-." for "Top-1", "Top-2", etc). Each regex string will be matched against the keys of the dictionary returned
+            by ``model.get_metrics()``. All matching metrics will be evaluated.
+
+            By default, if left blank, then all metrics returned by ``model.get_metrics()`` will be used.
         subset_num_batches (int, optional): The maximum number of batches to use for each evaluation. Defaults to ``None``,
             which means that the ``eval_subset_num_batches`` parameter from the :class:`.Trainer` will be used.
             Set to ``-1`` to evaluate the entire ``dataloader``
@@ -117,19 +147,26 @@ class Evaluator:
         *,
         label: str,
         dataloader: Union[DataSpec, Iterable, Dict[str, Any]],
-        metrics: Union[Metric, MetricCollection],
+        metric_names: Optional[List[str]] = None,
+        metrics: Optional[Union[Metric, MetricCollection]] = None,
         subset_num_batches: Optional[int] = None,
         eval_interval: Optional[Union[int, str, Time, Callable[[State, Event], bool]]] = None,
     ):
         self.label = label
         self.dataloader = ensure_data_spec(dataloader)
 
-        # Forcing metrics to be a MetricCollection simplifies logging results
-        metrics = copy.deepcopy(metrics)
-        if isinstance(metrics, Metric):
-            self.metrics = MetricCollection([metrics])
-        else:
-            self.metrics = metrics
+        self.metric_names = []
+        if metric_names or metrics:
+            if (metric_names and metrics):
+                raise ValueError('only one of ``metrics`` or ``metric_names`` should be specified.')
+            if metric_names:
+                self.metric_names = metric_names
+            elif metrics:
+                warnings.warn(DeprecationWarning('``metrics`` is deprecated and will be removed in a future release.'))
+                if isinstance(metrics, Metric):
+                    self.metric_names = [metrics.__class__.__name__]
+                else:
+                    self.metric_names = [str(k) for k, _ in metrics.items()]
 
         self.subset_num_batches = subset_num_batches
         self._eval_interval = None
@@ -149,15 +186,14 @@ class Evaluator:
             self._eval_interval = eval_interval
 
 
-def ensure_evaluator(evaluator: Union[Evaluator, DataSpec, Iterable, Dict[str, Any]],
-                     default_metrics: Union[Metric, MetricCollection]):
+def ensure_evaluator(evaluator: Union[Evaluator, DataSpec, Iterable, Dict[str, Any]], default_metric_names: List[str]):
     """Ensure that ``evaluator`` is an :class:`.Evaluator`.
 
     Args:
         evaluator (Evaluator | DataSpec | Iterable | Dict[str, Any]): A dataloader,
             :class:`.DataSpec` instance, dictionary of :class:`.DataSpec` kwargs, or existing evaluator.
-        default_metrics (torchmetrics.Metric | torchmetrics.MetricCollection): The metrics for the ``evaluator``,
-            if a datalaoder was specified.
+        default_metric_names (List[str]): The names of the metrics for the ``evaluator``,
+            if a dataloader was specified.
 
     Returns:
         Evaluator: An evaluator.
@@ -168,5 +204,5 @@ def ensure_evaluator(evaluator: Union[Evaluator, DataSpec, Iterable, Dict[str, A
         return Evaluator(
             label='eval',
             dataloader=evaluator,
-            metrics=default_metrics,
+            metric_names=default_metric_names,
         )
