@@ -30,7 +30,7 @@ class InMemoryLogger(LoggerDestination):
     Example usage:
         .. testcode::
 
-            from composer.loggers import InMemoryLogger, LogLevel
+            from composer.loggers import InMemoryLogger
             from composer.trainer import Trainer
             logger = InMemoryLogger(
             )
@@ -47,7 +47,7 @@ class InMemoryLogger(LoggerDestination):
             logged_data = trainer.logger.destinations[0].data
 
     Attributes:
-        data (Dict[str, List[Tuple[Timestamp, LogLevel, Any]]]): Mapping of a logged key to
+        data (Dict[str, List[Tuple[Timestamp, Any]]]): Mapping of a logged key to
             a (:class:`~.time.Timestamp`, logged value) tuple.
             This dictionary contains all logged data.
         most_recent_values (Dict[str, Any]): Mapping of a key to the most recent value for that key.
