@@ -9,9 +9,9 @@ image resolution according to an empirically determined scaling law.
 See the :doc:`Model Card </model_cards/efficientnet>` for more details.
 """
 from composer.models.efficientnetb0.efficientnetb0_hparams import EfficientNetB0Hparams as EfficientNetB0Hparams
-from composer.models.efficientnetb0.model import EfficientNetB0 as EfficientNetB0
+from composer.models.efficientnetb0.model import composer_efficientnetb0 as composer_efficientnetb0
 
-__all__ = ['EfficientNetB0', 'EfficientNetB0Hparams']
+__all__ = ['composer_efficientnetb0', 'EfficientNetB0Hparams']
 
 _task = 'Image Classification'
 _dataset = 'ImageNet'
