@@ -1,7 +1,7 @@
 # Copyright 2022 MosaicML Composer authors
 # SPDX-License-Identifier: Apache-2.0
 
-"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.EfficientNetB0`."""
+"""`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :func:`.composer_efficientnetb0`."""
 
 from dataclasses import dataclass
 
@@ -14,7 +14,8 @@ __all__ = ['EfficientNetB0Hparams']
 
 @dataclass
 class EfficientNetB0Hparams(ModelHparams):
-    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for :class:`.EfficientNetB0`.
+    """`YAHP <https://docs.mosaicml.com/projects/yahp/en/stable/README.html>`_ interface for
+        :func:`.composer_efficientnetb0`.
 
     Args:
         num_classes (int, optional): The number of classes. Needed for classification tasks. Default: ``1000``.
@@ -29,5 +30,5 @@ class EfficientNetB0Hparams(ModelHparams):
         if self.num_classes is None:
             raise ValueError('EfficientNet requires num_classes to be specified.')
 
-        from composer.models.efficientnetb0.model import EfficientNetB0
-        return EfficientNetB0(num_classes=self.num_classes, drop_connect_rate=self.drop_connect_rate)
+        from composer.models.efficientnetb0.model import composer_efficientnetb0
+        return composer_efficientnetb0(num_classes=self.num_classes, drop_connect_rate=self.drop_connect_rate)
